# SearchXNG with Tailscale Integration

![SearchXNG with Tailscale](https://raw.githubusercontent.com/searxng/searxng/master/client/simple/src/brand/searxng.svg "SearchXNG")

This project sets up a SearchXNG instance with Tailscale VPN integration using Docker Compose. It creates a secure, private network connection for your SearchXNG instance using Tailscale.

## Prerequisites

- Docker and Docker Compose installed on your system
- A Tailscale account and auth key (get one from https://login.tailscale.com/admin/authkeys)
- Tailscale SSL/TLS enabled (toggled in tailscale admin page)
- Basic understanding of Docker and networking concepts

## Project Structure
```
ts-searchxng/
├── docker-compose.yml
├── tailscale/
│   ├── tailscale-data/     # Persistent Tailscale state
│   └── config/             # Tailscale configuration files
└── searchxng/
    └── config/             # SearchXNG configuration files
```

## Setup Instructions

1. **Clone the Repository**
   ```bash
   git clone https://gitea.damconsulting.llc/DAM/ts-searchxng
   cd ts-searchxng
   ```
2. Create Required Directories
    ```bash
    mkdir -p tailscale/tailscale-data
    mkdir -p searchxng
    ```
3. Configure Tailscale
    - Replace `{{YOUR_TAILSCALE_AUTHKEY}}` in the docker-compose.yml with your actual Tailscale auth key
    - Optionally, update the file in `tailscale/config/serve.json` if you need specific Tailscale serve configurations
        - CAUTION: Changing `"${TS_CERT_DOMAIN}:443": false` to `true` will expose the service to the internet

4. Configure SearchXNG
    - Replace `{{YOUR_TAILNET_DOMAIN}}` in the docker-compose.yml with your actual Tailscale domain name
    - See the [documentation](https://docs.searxng.org/admin/settings/index.html) for configuration options

5. Start the Services
    ```bash
    docker compose up -d
    ```

6. Wait for Certificate to propagate [~2m] 

7. Login 
    - After starting the services your service should be available via tailnet at https://searchxng.{{YOUR_TAILNET_DOMAIN}}.ts.net ie https://searchxng.tail12345.ts.net/

## Services

### searchxng-ts (Tailscale)

- Runs Tailscale VPN client
- Image: tailscale/tailscale:latest
- Container name: searchxng-ts
- Hostname: searchxng
- Requires NET_ADMIN and SYS_MODULE capabilities
- Persists state in ./tailscale/tailscale-data
- Uses configuration from ./tailscale/config

### searchxng

- Depends on searchxng-ts service

## Usage

- After starting the services your service should be available via tailnet at `https://searchxng.{{YOUR_TAILNET_DOMAIN}}.ts.net` ie `https://searchxng.tail12345.ts.net/`
- To manually get the Tailscale IP/hostname of your container:
    ```bash
    docker logs searchxng-ts
    ```
    Look for the Tailscale IP address in the logs.

## Optional Features

- Uncomment and adjust the ports mapping if you need direct access (without Tailscale):
    ```yaml
    ports:
    - 8080:8080
    ```
- Stopping the Services
    ```bash
    docker compose down
    ```

## Troubleshooting
- Check container logs:
    ```bash
    docker logs searchxng-ts
    docker logs searchxng
    ```
- Ensure your Tailscale auth key is valid and not expired
- Verify the configuration files have proper permissions
- Make sure required directories exist before starting

## Notes
- The SearchXNG service uses the Tailscale service's network stack via `network_mode: service:searchxng-ts`
- Direct port mapping is disabled by default as Tailscale handles the networking
- Services restart automatically unless explicitly stopped
- For more information:
    - Tailscale documentation: https://tailscale.com/kb/
    - SearchXNG [documentation](https://docs.searxng.org/admin/settings/index.html)
    - SearchXNG [repository](https://github.com/searxng/searxng)